@@ -13,6 +13,7 @@ from pptx.chart.chart import Chart
 from pptx.dml.color import RGBColor
 from pptx.enum.dml import MSO_FILL, MSO_THEME_COLOR
 from pptx.enum.shapes import MSO_SHAPE, MSO_SHAPE_TYPE
+from pptx.action import ActionSetting
 from pptx.util import Inches
 
 from helpers import cls_qname, saved_pptx_path, test_pptx, test_text
@@ -20,6 +21,19 @@ from helpers import cls_qname, saved_pptx_path, test_pptx, test_text
 
 # given ===================================================
 
+@given('a chart')
+def given_a_chart(context):
+    prs = Presentation(test_pptx('shp-common-props'))
+    sld = prs.slides[0]
+    context.shape = sld.shapes[6]
+
+
+@given('a chevron shape')
+def given_a_chevron_shape(context):
+    prs = Presentation(test_pptx('shp-autoshape-adjustments'))
+    context.shape = prs.slides[0].shapes[0]
+
+
 @given('a connector')
 def given_a_connector(context):
     prs = Presentation(test_pptx('shp-common-props'))
@@ -28,7 +42,7 @@ def given_a_connector(context):
 
 
 @given('a graphic frame')  # shouldn't matter, but this one contains a table
-def given_a_table(context):
+def given_a_graphic_frame(context):
     prs = Presentation(test_pptx('shp-common-props'))
     sld = prs.slides[0]
     context.shape = sld.shapes[2]
@@ -83,6 +97,20 @@ def given_a_shape(context):
     context.shape = sld.shapes[0]
 
 
+@given('a table')
+def given_a_table(context):
+    prs = Presentation(test_pptx('shp-common-props'))
+    sld = prs.slides[0]
+    context.shape = sld.shapes[2]
+
+
+@given('a textbox')
+def given_a_textbox(context):
+    prs = Presentation(test_pptx('shp-common-props'))
+    sld = prs.slides[0]
+    context.shape = sld.shapes[5]
+
+
 @given('a {shape_type} on a slide')
 def given_a_shape_on_a_slide(context, shape_type):
     shape_idx = {
@@ -106,11 +134,8 @@ def given_a_shape_of_known_position_and_size(context):
 
 @given('an autoshape')
 def given_an_autoshape(context):
-    prs = Presentation()
-    blank_slide_layout = prs.slide_layouts[6]
-    shapes = prs.slides.add_slide(blank_slide_layout).shapes
-    x = y = cx = cy = 914400
-    context.shape = shapes.add_shape(MSO_SHAPE.ROUNDED_RECTANGLE, x, y, cx, cy)
+    prs = Presentation(test_pptx('shp-autoshape-adjustments'))
+    context.shape = prs.slides[0].shapes[0]
 
 
 @given('an autoshape having text')
@@ -119,15 +144,6 @@ def given_an_autoshape_having_text(context):
     context.shape = prs.slides[0].shapes[0]
 
 
-@given('I have a reference to a chevron shape')
-def given_ref_to_chevron_shape(context):
-    context.prs = Presentation()
-    blank_slide_layout = context.prs.slide_layouts[6]
-    shapes = context.prs.slides.add_slide(blank_slide_layout).shapes
-    x = y = cx = cy = 914400
-    context.chevron_shape = shapes.add_shape(MSO_SHAPE.CHEVRON, x, y, cx, cy)
-
-
 # when ====================================================
 
 @when("I add a text box to the slide's shape collection")
@@ -148,6 +164,11 @@ def when_I_add_an_auto_shape(context):
     sp.text = test_text
 
 
+@when("I assign 0.15 to shape.adjustments[0]")
+def when_I_assign_to_shape_adjustments(context):
+    context.shape.adjustments[0] = 0.15
+
+
 @when("I assign a string to shape.text")
 def when_I_assign_a_string_to_shape_text(context):
     context.shape.text = u'F\xf8o\nBar'
@@ -206,11 +227,6 @@ def when_set_fill_type_to_solid(context):
     context.shape.fill.solid()
 
 
-@when("I set the first adjustment value to 0.15")
-def when_set_first_adjustment_value(context):
-    context.chevron_shape.adjustments[0] = 0.15
-
-
 @when("I set the foreground color brightness to 0.5")
 def when_set_fore_color_brightness_to_value(context):
     context.shape.fill.fore_color.brightness = 0.5
@@ -228,6 +244,12 @@ def when_set_fore_color_to_RGB_value(context):
 
 # then ====================================================
 
+@then('shape.adjustments[0] is 0.15')
+def then_shape_adjustments_is_value(context):
+    shape = context.shape
+    assert shape.adjustments[0] == 0.15
+
+
 @then('the auto shape appears in the slide')
 def then_auto_shape_appears_in_slide(context):
     prs = Presentation(saved_pptx_path)
@@ -238,12 +260,6 @@ def then_auto_shape_appears_in_slide(context):
     assert sp_text == test_text
 
 
-@then('the chevron shape appears with a less acute arrow head')
-def then_chevron_shape_appears_with_less_acute_arrow_head(context):
-    chevron = Presentation(saved_pptx_path).slides[0].shapes[0]
-    assert chevron.adjustments[0] == 0.15
-
-
 @then('the fill type of the shape is background')
 def then_fill_type_is_background(context):
     assert context.shape.fill.type == MSO_FILL.BACKGROUND
@@ -276,9 +292,9 @@ def then_I_can_access_the_line_format_of_the_shape(context):
     )
 
 
-@then('I can access the slide from the shape')
-def then_I_can_access_the_slide_from_the_shape(context):
-    assert context.shape.part is context.slide
+@then('I can access the slide part from the shape')
+def then_I_can_access_the_slide_part_from_the_shape(context):
+    assert context.shape.part is context.slide.part
 
 
 @then('I can determine the shape {has_text_frame_status}')
@@ -302,6 +318,11 @@ def then_I_can_get_the_id_of_the_shape(context, shape_type):
     assert context.shape.id == expected_id
 
 
+@then("shape.click_action is an ActionSetting object")
+def then_shape_click_action_is_an_ActionSetting_object(context):
+    assert isinstance(context.shape.click_action, ActionSetting)
+
+
 @then("shape.name is '{expected_value}'")
 def then_shape_name_is_value(context, expected_value):
     shape = context.shape
