@@ -6,8 +6,12 @@ Axis-related chart objects.
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-from ..enum.chart import XL_TICK_LABEL_POSITION, XL_TICK_MARK
+from ..dml.chtfmt import ChartFormat
+from ..enum.chart import (
+    XL_AXIS_CROSSES, XL_TICK_LABEL_POSITION, XL_TICK_MARK
+)
 from ..oxml.ns import qn
+from ..shared import ElementProxy
 from ..text.text import Font
 from ..util import lazyproperty
 
@@ -17,9 +21,18 @@ class _BaseAxis(object):
     Base class for chart axis objects. All axis objects share these
     properties.
     """
-    def __init__(self, xAx_elm):
+    def __init__(self, xAx):
         super(_BaseAxis, self).__init__()
-        self._element = xAx_elm
+        self._element = xAx  # axis element, c:catAx or c:valAx
+        self._xAx = xAx
+
+    @lazyproperty
+    def format(self):
+        """
+        The |ChartFormat| object providing access to the shape formatting
+        properties of this axis, such as its line color and fill.
+        """
+        return ChartFormat(self._element)
 
     @property
     def has_major_gridlines(self):
@@ -59,6 +72,14 @@ class _BaseAxis(object):
         else:
             self._element._remove_minorGridlines()
 
+    @lazyproperty
+    def major_gridlines(self):
+        """
+        The |MajorGridlines| object representing the major gridlines for
+        this axis.
+        """
+        return MajorGridlines(self._element)
+
     @property
     def major_tick_mark(self):
         """
@@ -180,6 +201,28 @@ class CategoryAxis(_BaseAxis):
     """
 
 
+class MajorGridlines(ElementProxy):
+    """
+    Provides access to the properties of the major gridlines appearing on an
+    axis.
+    """
+
+    __slots__ = ('_xAx', '_format')
+
+    def __init__(self, xAx):
+        super(MajorGridlines, self).__init__(xAx)
+        self._xAx = xAx  # axis element, catAx or valAx
+
+    @lazyproperty
+    def format(self):
+        """
+        The |ChartFormat| object providing access to the shape formatting
+        properties of this data point, such as line and fill.
+        """
+        majorGridlines = self._xAx.get_or_add_majorGridlines()
+        return ChartFormat(majorGridlines)
+
+
 class TickLabels(object):
     """
     A service class providing access to formatting of axis tick mark labels.
@@ -265,8 +308,56 @@ class TickLabels(object):
 
 class ValueAxis(_BaseAxis):
     """
-    A value axis of a chart.
+    An axis having continuous (as opposed to discrete) values. The vertical
+    axis is generally a value axis, however both axes of an XY-type chart are
+    value axes.
     """
+    @property
+    def crosses(self):
+        """
+        Member of :ref:`XlAxisCrosses` enumeration specifying the point on
+        this axis where the other axis crosses, such as auto/zero, minimum,
+        or maximum. Returns `XL_AXIS_CROSSES.CUSTOM` when a specific numeric
+        crossing point (e.g. 1.5) is defined.
+        """
+        crosses = self._cross_xAx.crosses
+        if crosses is None:
+            return XL_AXIS_CROSSES.CUSTOM
+        return crosses.val
+
+    @crosses.setter
+    def crosses(self, value):
+        cross_xAx = self._cross_xAx
+        if value == XL_AXIS_CROSSES.CUSTOM:
+            if cross_xAx.crossesAt is not None:
+                return
+        cross_xAx._remove_crosses()
+        cross_xAx._remove_crossesAt()
+        if value == XL_AXIS_CROSSES.CUSTOM:
+            cross_xAx._add_crossesAt(val=0.0)
+        else:
+            cross_xAx._add_crosses(val=value)
+
+    @property
+    def crosses_at(self):
+        """
+        Numeric value on this axis at which the perpendicular axis crosses.
+        Returns |None| if no crossing value is set.
+        """
+        crossesAt = self._cross_xAx.crossesAt
+        if crossesAt is None:
+            return None
+        return crossesAt.val
+
+    @crosses_at.setter
+    def crosses_at(self, value):
+        cross_xAx = self._cross_xAx
+        cross_xAx._remove_crosses()
+        cross_xAx._remove_crossesAt()
+        if value is None:
+            return
+        cross_xAx._add_crossesAt(val=value)
+
     @property
     def major_unit(self):
         """
@@ -306,3 +397,14 @@ class ValueAxis(_BaseAxis):
         if value is None:
             return
         self._element._add_minorUnit(val=value)
+
+    @property
+    def _cross_xAx(self):
+        """
+        The axis element in the same group (primary/secondary) that crosses
+        this axis.
+        """
+        crossAx_id = self._element.crossAx.val
+        expr = '(../c:catAx | ../c:valAx)/c:axId[@val="%d"]' % crossAx_id
+        cross_axId = self._element.xpath(expr)[0]
+        return cross_axId.getparent()
