@@ -5,7 +5,9 @@ Initializes lxml parser and makes available a handful of functions that wrap
 its typical uses.
 """
 
-from __future__ import absolute_import
+from __future__ import (
+    absolute_import, division, print_function, unicode_literals
+)
 
 from lxml import etree
 
@@ -14,7 +16,7 @@ from .ns import NamespacePrefixedTag
 
 # configure etree XML parser -------------------------------
 element_class_lookup = etree.ElementNamespaceClassLookup()
-oxml_parser = etree.XMLParser(remove_blank_text=True)
+oxml_parser = etree.XMLParser(remove_blank_text=True, resolve_entities=False)
 oxml_parser.set_element_class_lookup(element_class_lookup)
 
 
@@ -38,19 +40,26 @@ def register_element_cls(nsptagname, cls):
     namespace[nsptag.local_part] = cls
 
 
+from .action import CT_Hyperlink
+register_element_cls('a:hlinkClick', CT_Hyperlink)
+register_element_cls('a:hlinkHover', CT_Hyperlink)
+
+
 from .chart.axis import (
-    CT_AxisUnit, CT_CatAx, CT_LblOffset, CT_Scaling, CT_TickLblPos,
-    CT_TickMark, CT_ValAx
+    CT_AxisUnit, CT_CatAx, CT_ChartLines, CT_Crosses, CT_LblOffset,
+    CT_Scaling, CT_TickLblPos, CT_TickMark, CT_ValAx
 )
-register_element_cls('c:catAx',         CT_CatAx)
-register_element_cls('c:lblOffset',     CT_LblOffset)
-register_element_cls('c:majorTickMark', CT_TickMark)
-register_element_cls('c:majorUnit',     CT_AxisUnit)
-register_element_cls('c:minorTickMark', CT_TickMark)
-register_element_cls('c:minorUnit',     CT_AxisUnit)
-register_element_cls('c:scaling',       CT_Scaling)
-register_element_cls('c:tickLblPos',    CT_TickLblPos)
-register_element_cls('c:valAx',         CT_ValAx)
+register_element_cls('c:catAx',          CT_CatAx)
+register_element_cls('c:crosses',        CT_Crosses)
+register_element_cls('c:lblOffset',      CT_LblOffset)
+register_element_cls('c:majorGridlines', CT_ChartLines)
+register_element_cls('c:majorTickMark',  CT_TickMark)
+register_element_cls('c:majorUnit',      CT_AxisUnit)
+register_element_cls('c:minorTickMark',  CT_TickMark)
+register_element_cls('c:minorUnit',      CT_AxisUnit)
+register_element_cls('c:scaling',        CT_Scaling)
+register_element_cls('c:tickLblPos',     CT_TickLblPos)
+register_element_cls('c:valAx',          CT_ValAx)
 
 
 from .chart.chart import (
@@ -63,39 +72,64 @@ register_element_cls('c:plotArea',     CT_PlotArea)
 register_element_cls('c:style',        CT_Style)
 
 
+from .chart.datalabel import CT_DLbl, CT_DLblPos, CT_DLbls
+register_element_cls('c:dLbl',    CT_DLbl)
+register_element_cls('c:dLblPos', CT_DLblPos)
+register_element_cls('c:dLbls',   CT_DLbls)
+
+
 from .chart.legend import CT_Legend, CT_LegendPos
 register_element_cls('c:legend',    CT_Legend)
 register_element_cls('c:legendPos', CT_LegendPos)
 
 
+from .chart.marker import CT_Marker, CT_MarkerSize, CT_MarkerStyle
+register_element_cls('c:marker', CT_Marker)
+register_element_cls('c:size',   CT_MarkerSize)
+register_element_cls('c:symbol', CT_MarkerStyle)
+
+
 from .chart.plot import (
-    CT_Area3DChart, CT_AreaChart, CT_BarChart, CT_BarDir, CT_DLblPos,
-    CT_DLbls, CT_GapAmount, CT_Grouping, CT_LineChart, CT_Overlap,
-    CT_PieChart
+    CT_Area3DChart, CT_AreaChart, CT_BarChart, CT_BarDir, CT_BubbleChart,
+    CT_BubbleScale, CT_DoughnutChart, CT_GapAmount, CT_Grouping,
+    CT_LineChart, CT_Overlap, CT_PieChart, CT_RadarChart, CT_ScatterChart
 )
-register_element_cls('c:area3DChart', CT_Area3DChart)
-register_element_cls('c:areaChart',   CT_AreaChart)
-register_element_cls('c:barChart',    CT_BarChart)
-register_element_cls('c:barDir',      CT_BarDir)
-register_element_cls('c:dLblPos',     CT_DLblPos)
-register_element_cls('c:dLbls',       CT_DLbls)
-register_element_cls('c:gapWidth',    CT_GapAmount)
-register_element_cls('c:grouping',    CT_Grouping)
-register_element_cls('c:lineChart',   CT_LineChart)
-register_element_cls('c:overlap',     CT_Overlap)
-register_element_cls('c:pieChart',    CT_PieChart)
+register_element_cls('c:area3DChart',   CT_Area3DChart)
+register_element_cls('c:areaChart',     CT_AreaChart)
+register_element_cls('c:barChart',      CT_BarChart)
+register_element_cls('c:barDir',        CT_BarDir)
+register_element_cls('c:bubbleChart',   CT_BubbleChart)
+register_element_cls('c:bubbleScale',   CT_BubbleScale)
+register_element_cls('c:doughnutChart', CT_DoughnutChart)
+register_element_cls('c:gapWidth',      CT_GapAmount)
+register_element_cls('c:grouping',      CT_Grouping)
+register_element_cls('c:lineChart',     CT_LineChart)
+register_element_cls('c:overlap',       CT_Overlap)
+register_element_cls('c:pieChart',      CT_PieChart)
+register_element_cls('c:radarChart',    CT_RadarChart)
+register_element_cls('c:scatterChart',  CT_ScatterChart)
 
 
-from .chart.series import CT_SeriesComposite, CT_StrVal_NumVal_Composite
-register_element_cls('c:pt',  CT_StrVal_NumVal_Composite)
-register_element_cls('c:ser', CT_SeriesComposite)
+from .chart.series import (
+    CT_DPt, CT_NumDataSource, CT_SeriesComposite, CT_StrVal_NumVal_Composite
+)
+register_element_cls('c:bubbleSize', CT_NumDataSource)
+register_element_cls('c:dPt',        CT_DPt)
+register_element_cls('c:pt',         CT_StrVal_NumVal_Composite)
+register_element_cls('c:ser',        CT_SeriesComposite)
+register_element_cls('c:val',        CT_NumDataSource)
+register_element_cls('c:xVal',       CT_NumDataSource)
+register_element_cls('c:yVal',       CT_NumDataSource)
 
 
 from .chart.shared import (
     CT_Boolean, CT_Double, CT_Layout, CT_LayoutMode, CT_ManualLayout,
-    CT_NumFmt, CT_UnsignedInt
+    CT_NumFmt, CT_Tx, CT_UnsignedInt
 )
 register_element_cls('c:autoUpdate',       CT_Boolean)
+register_element_cls('c:bubble3D',         CT_Boolean)
+register_element_cls('c:crossAx',          CT_UnsignedInt)
+register_element_cls('c:crossesAt',        CT_Double)
 register_element_cls('c:delete',           CT_Boolean)
 register_element_cls('c:idx',              CT_UnsignedInt)
 register_element_cls('c:invertIfNegative', CT_Boolean)
@@ -106,12 +140,18 @@ register_element_cls('c:min',              CT_Double)
 register_element_cls('c:numFmt',           CT_NumFmt)
 register_element_cls('c:order',            CT_UnsignedInt)
 register_element_cls('c:overlay',          CT_Boolean)
+register_element_cls('c:showLegendKey',    CT_Boolean)
 register_element_cls('c:smooth',           CT_Boolean)
+register_element_cls('c:tx',               CT_Tx)
 register_element_cls('c:varyColors',       CT_Boolean)
 register_element_cls('c:x',                CT_Double)
 register_element_cls('c:xMode',            CT_LayoutMode)
 
 
+from .coreprops import CT_CoreProperties
+register_element_cls('cp:coreProperties', CT_CoreProperties)
+
+
 from .dml.color import (
     CT_HslColor, CT_Percentage, CT_PresetColor, CT_SchemeColor,
     CT_ScRgbColor, CT_SRgbColor, CT_SystemColor
@@ -141,11 +181,19 @@ register_element_cls('a:solidFill', CT_SolidColorFillProperties)
 register_element_cls('a:srcRect',   CT_RelativeRect)
 
 
-from .parts.coreprops import CT_CoreProperties
-register_element_cls('cp:coreProperties', CT_CoreProperties)
+from .slide import (
+    CT_CommonSlideData, CT_Slide, CT_SlideLayout, CT_SlideLayoutIdList,
+    CT_SlideLayoutIdListEntry, CT_SlideMaster
+)
+register_element_cls('p:cSld',           CT_CommonSlideData)
+register_element_cls('p:sld',            CT_Slide)
+register_element_cls('p:sldLayout',      CT_SlideLayout)
+register_element_cls('p:sldLayoutId',    CT_SlideLayoutIdListEntry)
+register_element_cls('p:sldLayoutIdLst', CT_SlideLayoutIdList)
+register_element_cls('p:sldMaster',      CT_SlideMaster)
 
 
-from .parts.presentation import (
+from .presentation import (
     CT_Presentation, CT_SlideId, CT_SlideIdList, CT_SlideMasterIdList,
     CT_SlideMasterIdListEntry, CT_SlideSize
 )
@@ -157,23 +205,6 @@ register_element_cls('p:sldMasterIdLst', CT_SlideMasterIdList)
 register_element_cls('p:sldSz',          CT_SlideSize)
 
 
-from .parts.slide import CT_CommonSlideData, CT_Slide
-register_element_cls('p:cSld', CT_CommonSlideData)
-register_element_cls('p:sld',  CT_Slide)
-
-
-from .parts.slidelayout import CT_SlideLayout
-register_element_cls('p:sldLayout', CT_SlideLayout)
-
-
-from .parts.slidemaster import (
-    CT_SlideLayoutIdList, CT_SlideLayoutIdListEntry, CT_SlideMaster
-)
-register_element_cls('p:sldLayoutId',    CT_SlideLayoutIdListEntry)
-register_element_cls('p:sldLayoutIdLst', CT_SlideLayoutIdList)
-register_element_cls('p:sldMaster',      CT_SlideMaster)
-
-
 from .shapes.autoshape import (
     CT_GeomGuide, CT_GeomGuideList, CT_NonVisualDrawingShapeProps,
     CT_PresetGeometry2D, CT_Shape, CT_ShapeNonVisual
@@ -247,7 +278,7 @@ register_element_cls('a:tr',      CT_TableRow)
 
 
 from .text import (
-    CT_Hyperlink, CT_RegularTextRun, CT_TextBody, CT_TextBodyProperties,
+    CT_RegularTextRun, CT_TextBody, CT_TextBodyProperties,
     CT_TextCharacterProperties, CT_TextField, CT_TextFont, CT_TextLineBreak,
     CT_TextNormalAutofit, CT_TextParagraph, CT_TextParagraphProperties,
     CT_TextSpacing, CT_TextSpacingPercent, CT_TextSpacingPoint
@@ -257,13 +288,13 @@ register_element_cls('a:br',          CT_TextLineBreak)
 register_element_cls('a:defRPr',      CT_TextCharacterProperties)
 register_element_cls('a:endParaRPr',  CT_TextCharacterProperties)
 register_element_cls('a:fld',         CT_TextField)
-register_element_cls('a:hlinkClick',  CT_Hyperlink)
 register_element_cls('a:latin',       CT_TextFont)
 register_element_cls('a:lnSpc',       CT_TextSpacing)
 register_element_cls('a:normAutofit', CT_TextNormalAutofit)
 register_element_cls('a:r',           CT_RegularTextRun)
 register_element_cls('a:p',           CT_TextParagraph)
 register_element_cls('a:pPr',         CT_TextParagraphProperties)
+register_element_cls('c:rich',        CT_TextBody)
 register_element_cls('a:rPr',         CT_TextCharacterProperties)
 register_element_cls('a:spcAft',      CT_TextSpacing)
 register_element_cls('a:spcBef',      CT_TextSpacing)
