@@ -10,7 +10,7 @@ from .. import parse_xml
 from ..ns import nsdecls, qn
 from ..simpletypes import ST_Style, XsdString
 from ..xmlchemy import (
-    BaseOxmlElement, OneAndOnlyOne, RequiredAttribute, ZeroOrOne
+    BaseOxmlElement, OneAndOnlyOne, RequiredAttribute, ZeroOrMore, ZeroOrOne
 )
 
 
@@ -28,10 +28,6 @@ class CT_Chart(BaseOxmlElement):
         '<c:chart %s %s r:id="%%s"/>' % (nsdecls('c'), nsdecls('r'))
     )
 
-    @property
-    def catAx(self):
-        return self.plotArea.catAx
-
     @property
     def has_legend(self):
         """
@@ -65,10 +61,6 @@ class CT_Chart(BaseOxmlElement):
         chart = parse_xml(xml)
         return chart
 
-    @property
-    def valAx(self):
-        return self.plotArea.valAx
-
 
 class CT_ChartSpace(BaseOxmlElement):
     """
@@ -83,8 +75,8 @@ class CT_ChartSpace(BaseOxmlElement):
     ))
 
     @property
-    def catAx(self):
-        return self.chart.catAx
+    def catAx_lst(self):
+        return self.chart.plotArea.catAx_lst
 
     @property
     def last_doc_order_ser(self):
@@ -117,8 +109,8 @@ class CT_ChartSpace(BaseOxmlElement):
         return sers
 
     @property
-    def valAx(self):
-        return self.chart.valAx
+    def valAx_lst(self):
+        return self.chart.plotArea.valAx_lst
 
     @property
     def xlsx_part_rId(self):
@@ -156,9 +148,8 @@ class CT_PlotArea(BaseOxmlElement):
     """
     ``<c:plotArea>`` element.
     """
-    # catAx and valAx are actually ZeroOrMore, but don't need list bit yet
-    catAx = ZeroOrOne('c:catAx')
-    valAx = ZeroOrOne('c:valAx')
+    catAx = ZeroOrMore('c:catAx')
+    valAx = ZeroOrMore('c:valAx')
 
     def iter_plots(self):
         """
