@@ -8,21 +8,44 @@ from __future__ import (
     absolute_import, division, print_function, unicode_literals
 )
 
-from .autoshape import AutoShapeType
+from .autoshape import AutoShapeType, Shape
+from .base import BaseShape
 from ..enum.shapes import PP_PLACEHOLDER
-from .factory import BaseShapeFactory, SlideShapeFactory
+from .graphfrm import GraphicFrame
+from ..oxml.ns import qn
 from ..oxml.shapes.graphfrm import CT_GraphicalObjectFrame
 from ..oxml.simpletypes import ST_Direction
+from .picture import Picture
+from .placeholder import (
+    ChartPlaceholder, LayoutPlaceholder, MasterPlaceholder,
+    PicturePlaceholder, PlaceholderGraphicFrame, PlaceholderPicture,
+    SlidePlaceholder, TablePlaceholder
+)
+from ..shared import ParentedElementProxy
 
 
-class BaseShapeTree(object):
+def BaseShapeFactory(shape_elm, parent):
+    """
+    Return an instance of the appropriate shape proxy class for *shape_elm*.
+    """
+    tag_name = shape_elm.tag
+    if tag_name == qn('p:sp'):
+        return Shape(shape_elm, parent)
+    if tag_name == qn('p:pic'):
+        return Picture(shape_elm, parent)
+    if tag_name == qn('p:graphicFrame'):
+        return GraphicFrame(shape_elm, parent)
+    return BaseShape(shape_elm, parent)
+
+
+class _BaseShapes(ParentedElementProxy):
     """
     Base class for a shape collection appearing in a slide-type object,
     include Slide, SlideLayout, and SlideMaster, providing common methods.
     """
-    def __init__(self, slide):
-        super(BaseShapeTree, self).__init__()
-        self._slide = slide
+    def __init__(self, spTree, parent):
+        super(_BaseShapes, self).__init__(spTree, parent)
+        self._spTree = spTree
 
     def __getitem__(self, idx):
         """
@@ -51,14 +74,6 @@ class BaseShapeTree(object):
         shape_elms = list(self._iter_member_elms())
         return len(shape_elms)
 
-    @property
-    def part(self):
-        """
-        The package part containing this object, a _BaseSlide subclass in
-        this case.
-        """
-        return self._slide
-
     @staticmethod
     def _is_member_elm(shape_elm):
         """
@@ -72,8 +87,7 @@ class BaseShapeTree(object):
         Generate each child of the ``<p:spTree>`` element that corresponds to
         a shape, in the sequence they appear in the XML.
         """
-        spTree = self._slide.spTree
-        for shape_elm in spTree.iter_shape_elms():
+        for shape_elm in self._spTree.iter_shape_elms():
             if self._is_member_elm(shape_elm):
                 yield shape_elm
 
@@ -98,15 +112,8 @@ class BaseShapeTree(object):
         """
         return BaseShapeFactory(shape_elm, self)
 
-    @property
-    def _spTree(self):
-        """
-        The ``<p:spTree>`` element underlying this shape tree object
-        """
-        return self._slide.spTree
 
-
-class BasePlaceholders(BaseShapeTree):
+class BasePlaceholders(_BaseShapes):
     """
     Base class for placeholder collections that differentiate behaviors for
     a master, layout, and slide.
@@ -119,7 +126,172 @@ class BasePlaceholders(BaseShapeTree):
         return shape_elm.has_ph_elm
 
 
-class SlideShapeTree(BaseShapeTree):
+class LayoutPlaceholders(BasePlaceholders):
+    """
+    Sequence of |LayoutPlaceholder| instances representing the placeholder
+    shapes on a slide layout.
+    """
+    def get(self, idx, default=None):
+        """
+        Return the first placeholder shape with matching *idx* value, or
+        *default* if not found.
+        """
+        for placeholder in self:
+            if placeholder.idx == idx:
+                return placeholder
+        return default
+
+    def _shape_factory(self, shape_elm):
+        """
+        Return an instance of the appropriate shape proxy class for
+        *shape_elm*.
+        """
+        return _LayoutShapeFactory(shape_elm, self)
+
+
+def _LayoutShapeFactory(shape_elm, parent):
+    """
+    Return an instance of the appropriate shape proxy class for *shape_elm*
+    on a slide layout.
+    """
+    tag_name = shape_elm.tag
+    if tag_name == qn('p:sp') and shape_elm.has_ph_elm:
+        return LayoutPlaceholder(shape_elm, parent)
+    return BaseShapeFactory(shape_elm, parent)
+
+
+class LayoutShapes(_BaseShapes):
+    """
+    Sequence of shapes appearing on a slide layout. The first shape in the
+    sequence is the backmost in z-order and the last shape is topmost.
+    Supports indexed access, len(), index(), and iteration.
+    """
+    def _shape_factory(self, shape_elm):
+        """
+        Return an instance of the appropriate shape proxy class for
+        *shape_elm*.
+        """
+        return _LayoutShapeFactory(shape_elm, self)
+
+
+class MasterPlaceholders(BasePlaceholders):
+    """
+    Sequence of _MasterPlaceholder instances representing the placeholder
+    shapes on a slide master.
+    """
+    def get(self, ph_type, default=None):
+        """
+        Return the first placeholder shape with type *ph_type* (e.g. 'body'),
+        or *default* if no such placeholder shape is present in the
+        collection.
+        """
+        for placeholder in self:
+            if placeholder.ph_type == ph_type:
+                return placeholder
+        return default
+
+    def _shape_factory(self, shape_elm):
+        """
+        Return an instance of the appropriate shape proxy class for
+        *shape_elm*.
+        """
+        return _MasterShapeFactory(shape_elm, self)
+
+
+class MasterShapes(_BaseShapes):
+    """
+    Sequence of shapes appearing on a slide master. The first shape in the
+    sequence is the backmost in z-order and the last shape is topmost.
+    Supports indexed access, len(), and iteration.
+    """
+    def _shape_factory(self, shape_elm):
+        """
+        Return an instance of the appropriate shape proxy class for
+        *shape_elm*.
+        """
+        return _MasterShapeFactory(shape_elm, self)
+
+
+def _MasterShapeFactory(shape_elm, parent):
+    """
+    Return an instance of the appropriate shape proxy class for *shape_elm*
+    on a slide master.
+    """
+    tag_name = shape_elm.tag
+    if tag_name == qn('p:sp') and shape_elm.has_ph_elm:
+        return MasterPlaceholder(shape_elm, parent)
+    return BaseShapeFactory(shape_elm, parent)
+
+
+def _SlidePlaceholderFactory(shape_elm, parent):
+    """
+    Return a placeholder shape of the appropriate type for *shape_elm*.
+    """
+    tag = shape_elm.tag
+    if tag == qn('p:sp'):
+        Constructor = {
+            PP_PLACEHOLDER.BITMAP:  PicturePlaceholder,
+            PP_PLACEHOLDER.CHART:   ChartPlaceholder,
+            PP_PLACEHOLDER.PICTURE: PicturePlaceholder,
+            PP_PLACEHOLDER.TABLE:   TablePlaceholder,
+        }.get(shape_elm.ph_type, SlidePlaceholder)
+    elif tag == qn('p:graphicFrame'):
+        Constructor = PlaceholderGraphicFrame
+    elif tag == qn('p:pic'):
+        Constructor = PlaceholderPicture
+    else:
+        Constructor = BaseShapeFactory
+    return Constructor(shape_elm, parent)
+
+
+class SlidePlaceholders(ParentedElementProxy):
+    """
+    Collection of placeholder shapes on a slide. Supports iteration,
+    :func:`len`, and dictionary-style lookup on the `idx` value of the
+    placeholders it contains.
+    """
+
+    __slots__ = ()
+
+    def __getitem__(self, idx):
+        """
+        Access placeholder shape having *idx*. Note that while this looks
+        like list access, idx is actually a dictionary key and will raise
+        |KeyError| if no placeholder with that idx value is in the
+        collection.
+        """
+        for e in self._element.iter_ph_elms():
+            if e.ph_idx == idx:
+                return SlideShapeFactory(e, self)
+        raise KeyError('no placeholder on this slide with idx == %d' % idx)
+
+    def __iter__(self):
+        """
+        Generate placeholder shapes in `idx` order.
+        """
+        ph_elms = sorted(
+            [e for e in self._element.iter_ph_elms()], key=lambda e: e.ph_idx
+        )
+        return (SlideShapeFactory(e, self) for e in ph_elms)
+
+    def __len__(self):
+        """
+        Return count of placeholder shapes.
+        """
+        return len(list(self._element.iter_ph_elms()))
+
+
+def SlideShapeFactory(shape_elm, parent):
+    """
+    Return an instance of the appropriate shape proxy class for *shape_elm*
+    on a slide.
+    """
+    if shape_elm.has_ph_elm:
+        return _SlidePlaceholderFactory(shape_elm, parent)
+    return BaseShapeFactory(shape_elm, parent)
+
+
+class SlideShapes(_BaseShapes):
     """
     Sequence of shapes appearing on a slide. The first shape in the sequence
     is the backmost in z-order and the last shape is topmost. Supports indexed
@@ -146,12 +318,11 @@ class SlideShapeTree(BaseShapeTree):
         *image_file* can be either a path to a file (a string) or a file-like
         object.
         """
-        image_part, rId = self._slide.get_or_add_image_part(image_file)
+        image_part, rId = self.part.get_or_add_image_part(image_file)
         pic = self._add_pic_from_image_part(
             image_part, rId, left, top, width, height
         )
-        picture = self._shape_factory(pic)
-        return picture
+        return self._shape_factory(pic)
 
     def add_shape(self, autoshape_type_id, left, top, width, height):
         """
@@ -162,8 +333,7 @@ class SlideShapeTree(BaseShapeTree):
         sp = self._add_sp_from_autoshape_type(
             autoshape_type, left, top, width, height
         )
-        shape = self._shape_factory(sp)
-        return shape
+        return self._shape_factory(sp)
 
     def add_table(self, rows, cols, left, top, width, height):
         """
@@ -211,10 +381,10 @@ class SlideShapeTree(BaseShapeTree):
     @property
     def placeholders(self):
         """
-        Instance of |_SlidePlaceholders| containing sequence of placeholder
+        Instance of |SlidePlaceholders| containing sequence of placeholder
         shapes in this slide.
         """
-        return self._slide.placeholders
+        return self.parent.placeholders
 
     @property
     def title(self):
@@ -222,7 +392,7 @@ class SlideShapeTree(BaseShapeTree):
         The title placeholder shape on the slide or |None| if the slide has
         no title placeholder.
         """
-        for elm in self._spTree.iter_shape_elms():
+        for elm in self._spTree.iter_ph_elms():
             if elm.ph_idx == 0:
                 return self._shape_factory(elm)
         return None
@@ -255,10 +425,10 @@ class SlideShapeTree(BaseShapeTree):
         Return a newly added ``<p:graphicFrame>`` element containing a table
         as specified by the parameters.
         """
-        id_ = self._next_shape_id
-        name = 'Table %d' % (id_-1)
+        _id = self._next_shape_id
+        name = 'Table %d' % (_id-1)
         graphicFrame = self._spTree.add_table(
-            id_, name, rows, cols, x, y, cx, cy
+            _id, name, rows, cols, x, y, cx, cy
         )
         return graphicFrame
 
